Handbook - Epithelial System Interfacial Cells
Description: WormAtlas: A database of behavioral and structural anatomy of Caenorhabditis elegans.
Keywords: Caenorhabditis, elegans, anatomy, hermaphrodite, worm, nematode

Home Handbooks Hermaphrodite Male Dauer Embryo Aging P. pacificus S. stercoralis Resources WormImage Slidable Worm WormWiring Hall Lab Anatomical Methods Glossary of Terms Movie Gallery Individual Neurons Neurons & Circuits Worm Literature Cell Identification Cell Lineages Cell List Sperm Gallery Digital Development DIC PharynxAtlas User Guides Abbreviations Color Codes Copyright and Use How to Cite Links WormBase WormBook CGC WormGUIDES CytoSHOW OpenWorm Nemanode CeNGEN C. elegans Natural Diversity Anatomy by DIC - by J. Yochem About Us Mission Statement Contact

EPITHELIAL SYSTEM INTERFACIAL EPITHELIAL CELLS Click pictures for new window with figure and legend, click again for high resolution image
1 Overview Interfacial epithelial cells are located at the interface between the hypodermis and another type of tissue, at the points where these tissues attach to the hypodermis or open to outside through holes in the hypodermis. They are often intermediate in function and morphology between hypodermis and these adjacent tissues. They arrange in toroidal conformations that surround the junction site. All have epithelial characteristics and some secrete cuticle, forming smooth transitions between cuticles with different compositions (White, 1988). Interfacial epithelial cells include arcade cells and the pharyngeal epithelium of the buccal cavity, the vulval epithelium at the vulval opening, the rectal epithelium at the rectal canal and anus (proctodeum), socket and sheath cells (glia) at sensory openings, and the duct cell and pore cell forming the excretory pore. Detailed discussions of these cells, except for the arcades, are provided in chapters regarding the alimentary system (pharyngeal epithelium and rectal epithelium), the reproductive system (vulval epithelium), the nervous system (glia) and the excretory system (the duct and pore cells). In males, rectal epithelial cells generate the cloacal-gonadal connection (see Proctodeum), instead of rectal canal and anus (see also Male Anatomy).
2 Arcade Cells The anterior hypodermis consists of three specialized rings of cells (hyp1, hyp2, hyp3; cheilostom) (see HypFIG 10) that outline the anteriormost edge of the bodywall at the mouth and lips. The anterior end of the pharynx consists of an interfacial cell group known as the pharyngeal epithelium. Spanning the gap between hyp1 and the pharyngeal epithelium are the arcade cells (InterFIG 1) (Mango, 2007). Together, arcade cells and the pharyngeal epithelium form the buccal cavity and link the digestive tract to the outside and to body hypodermis. InterFIG 1: Structure of the buccal cavity. A. Horizontal section through the buccal capsule of an adult animal. (TEM; inset shows the plane of section; anterior is top.) Various cell types (dotted lines on the right lip) occupy the lips, which enclose the buccal cavity. The outermost layer is hyp 4 (h4), which connects to hyp 3 (h3) at the anterior and body wall muscle (BWmu) at the interior. hyp 3, in turn, connects to hyp 2 (h2) and a sensillar socket cell (So). On the cavity side, hyp 1 ring (h1) is bordered by the anterior (aa) and posterior (pa) arcade rings. The posterior third of the cavity is enclosed by the pharyngeal epithelial cells (e1, e3). Pharyngeal muscles (pm1, pm2) are seen behind the cuticular flaps. The amphid sheath (Amsh), which wraps the amphid processes, is located between body muscle and the arcades. The buccal cavity is lined by a cuticle which is distinct from the body cuticle (bc). The prostom cuticle (pc) is underlain by arcade cells (aa, pa), mesostom cuticle (mc) by pharyngeal epithelial cells (e1, e3), and metastom and telostom cuticle (m-tc) by pharyngeal muscle cells (pm1, pm2) (Wright and Thomson, 1981; Albert and Riddle, 1988). A posterior arcade process is shown on the left side of the image in lime green. Bar, 1 μm. (Image source: [Hall] B156-7821.) B. Representation of the buccal capsule in horizontal section (based on Dolinski et al., 1998). (Gray) Cuticle; (beige) hypodermis; (lime green) arcade cells; (purple) pharyngeal epithelium; (green and light green) pharynx muscle; (dark green) body wall muscle. (Dgo) Dorsal pharyngeal gland opening. C. Close-up of the cheilostom and the junction between body cuticle and buccal cuticle from the same image as in A. The cheilostom groove (arrow) is lined with body cuticle (bc) secreted from anterior hypodermal cells and the arcade cuticle (ac) secreted from the anterior arcade. These two cuticles have different compositions. The anterior arcade makes an extremely thin cylinder of tissue at its anterior margin (arrowhead). There are nine arcade cells that organize into two separate epithelial syncytia: the anterior arcade and the posterior arcade (InterFIG 2, InterMOVIE 1). Each of these syncytia has a cytoplasmic ring that surrounds the anterior of the buccal cavity (InterFIG 3). Their cell bodies, which are located in the body wall more posteriorly and close to the anterior bulb of pharynx, are connected to these rings by thin cytoplasmic processes (InterFIG 2 and InterFIG 4). Similar to other precursor cells of the buccal cavity, the arcade cells move inwards from their ventral position during embryogenesis, generating these processes (Wright and Thomson, 1981). In some cases cell fusion also occurs between these processes before reaching the syncytial ring. The anterior arcade ring is generated by the fusion of processes from three cells (arc ant DL, arc ant DR and arc ant V), whereas the posterior arcade ring is formed by the fusion of processes extended from six cells (arc post D, arc post DL, arc post DR, arc post V, arc post VL and arc post VR) (Wright and Thomson, 1981). InterFIG 2: Anterior and posterior arcade cells (as deduced from N2T adult animal). A. The localization of the arcade cells (lime green), the left amphid socket (Amso, pink) and the left lateral, dorsal and ventral midline anterior hypodermal cells (beige; numbered according to the hypodermis type), left lateral view. Anterior and posterior syncytial arcade rings cover the region between pharyngeal epithelium and the hyp 1 epithelial ring, which is made by hyp 1DR (not shown), hyp1DL and hyp1V. The positions of cells are determined from TEM sections of the N2T animal (MRC archive), and there may be slight variations between individual animals. (Ant. Bulb) Anterior bulb of the pharynx. Shown are only processes of the arcade and hyp 1 cells. B. Posterior arcade syncytium is made by six cells (arc post D, arc post DL, arc post DR, arc post V, arc post VL and arc post VR). Arcade cells are similar in shape to anterior hypodermal cells with cell bodies in the body wall at the posterior, a syncytial ring at the anterior, and with thin processes connecting the two. C. Three-dimensional view created from confocal images of a strain expressing the GFP marker linked to the promoter for C08C3.2, left lateral view. All six posterior arcade cells and the posterior arcade ring (arrowhead) are visible. Terminal bulb of the pharynx (arrow) is also expressing the marker gene. (Image source: R. Viverios & D. Moerman.) D. Anterior arcade syncytium is made by three cells (arc ant DL, arc ant DR and arc ant V). Similar to the posterior arcade, cell bodies of the syncytium are located posterior to the ring, between the tip and the anterior bulb of the pharynx. InterMOVIE 1: 3-D reconstruction of posterior arcade cells. 3-D movie was created from confocal images of a strain expressing the GFP marker linked to the promoter for C08C3.2 using Zeiss LSM 5 Pascal software v. 3.2. (Image source: R. Newbury and D. Moerman.) Click on image to play movie. InterFIG 3: Arcade cell bodies are located around the procorpus and anterior bulb of the pharynx. A. Epifluorescent image of the head of a transgenic animal expressing the F25B12.1::GFP reporter in arcade cells, medial left lateral view. Original magnification, 600x. (Strain source: The Genome BC C. elegans gene expression consortium; McKay et al., 2004.) Indicated are posterior (p) and anterior (a) arcade cell bodies. One of the anterior arcade cells is not visible in this focal plane. (Gray arrow) Process of a posterior arcade cell. B. DIC image of the same animal. Indicated are the nuclei of posterior (black arrowheads) and anterior (black arrows) arcade cells that are visible in this focal plane. (White arrows) Body wall muscle nuclei; (white arrowheads) nuclei of anterior hypodermal (hyp 4, hyp 6/7) cells, which are larger than arcade nuclei; (bc) buccal cavity. C. Overlay of DIC and epifluorescence images in A and B. D. TEM, longitudinal section close to midline of the anterior of the head of an adult animal. Indicated are three posterior arcade cells located on the dorsal side and one posterior arcade cell located on the ventral side of the pharynx procorpus. Posterior arcade ring is becoming visible in front of the procorpus. (BWmu) Body wall muscle. At this plane, the myofilament lattice of one muscle cell reaches the tip of the nose. Bar, Bar, 1 μm. (Image source: [Hall] B156-7778.) E. Epifluorescent image of an adult animal from a strain expressing the ajm-1::GFP reporter, lateral view. This marker gene is expressed at the apical borders of all epithelia. The two arcade rings (a) attach to each other and to neighboring tissues (pharyngeal epithelium [e] at the posterior, and hyp 1 at the anterior) via adherens junctions. Original magnification, 600x. (Strain source: H. Yu and P. W. Sternberg.) F. DIC image of the same animal as in E, showing the anterior of the pharynx and buccal cavity. Distinct domains of the buccal cavity and the anterior hypodermis are covered by various pharyngeal and epithelial cells. Abbreviations are the same as in InterFIG 1A; (arrow) cuticular flaps. G. Overlay of DIC and epifluorescence images in E and F. InterFIG 4: Arcade rings. TEM, transverse section; the level of the section is indicated in the top inset. Thin rings of anterior (opaque yellow) and posterior (transparent yellow) arcade tissue encircle the anterior two-thirds of the buccal cavity. Similar to hypodermal tissue, the rings have amorphous extensions (arrow) that insert around the neighboring tissues (visible [arrowhead] in the top inset). Posterior to the rings, the arcade tissues become two thin processes that run next to the pharyngeal procorpus (bottom inset). Bar, 1 μm. (Image source: [MRC] N2T A59-16.) The two arcade rings are firmly sealed to each other and to neighboring tissues via adherens junctions. The adherens junctions between the posterior arcade and the most anterior ring of pharyngeal epithelium are very robust and form one continuous belt desmosome along the entire border. The adherens junctions linking the two rings of arcade cells and the anterior arcade to the ring of hyp 1 syncytium are less robust. Preliminary evidence suggests that there are also gap junctions between these cells. Although not yet confirmed by examination at higher magnification, it appears that gap junctions link the two arcade rings to each other, and also possibly link the arcades to hyp 1 and to the anteriormost pharyngeal epithelial cells (D.H. Hall, unpublished). The arcade cell cytoplasm generally appears quite clear (electron lucent) compared to other epithelia, except for the portion closest to the buccal cavity, which often shows increased density at the plasma membrane. The arcade cells contain many free ribosomes and mitochondria, but very little endoplasmic reticulum (ER). Just prior to the molts, the arcade cells become filled with dense core vesicles that cluster near the cuticle, which suggests that the arcade cells build new cuticle by vesicle secretion (Wright and Thomson, 1981; D.H. Hall, unpublished; see Cuticle).
3 Buccal Cavity The nematode digestive system consists of three parts: the stomodeum, intestine and proctodeum (rectum and anus). Embryologically, the stomodeum and proctodeum have a mixed lineage derived from cells of both ectodermal and mesodermal origin, whereas intestine (gut) is wholly endodermal in origin. Stomodeum includes the mouth and the lips, the buccal cavity (stoma), and the pharynx (esophagus) (see Alimentary System for detailed descriptions of the pharynx, intestine, rectum and proctodeum). Rhabditids that feed on bacteria, such as C. elegans, have a relatively narrow and cylindrical, smoothly lined buccal cavity. In earlier literature this buccal cavity had been described as divided into five regions: cheilostom, prostom, mesostom, metastom and telostom, from anterior to posterior (Bird and Bird, 1991). More recently, however, throughout the class Secernentea, including Rhabditida, the cuticle-lined lumen of the buccal capsule has been subdivided from anterior to posterior into three chambers: the cheilostom, gymnostom, and stegostom (InterFIG 1B) (De Ley et al., 1995). Cheilostom is surrounded by hypodermis, gymnostom (former prostom) is surrounded by the pair of arcade syncytia, and stegostom (former mesostom, metastom and telostom) is surrounded by a longitudinal series of four sets of radial pharyngeal cells (e1, e3, pm1, pm2; see Alimentary System - Pharnyx) (Dolinski et al., 1998). In rhabditid nematodes, the specialized cuticular zones that line the mouth and the buccal passage have the suffix "rhabdia" (Bird and Bird, 1991). Hence, cheilorhabdion and prorhabdion refer to the cuticular coverings of the lips, and arcade regions, respectively, whereas mesorhabdion, metarhabdion and telorhabdion refer to the cuticular lining of the posterior buccal regions. Where the arcade tissue bridges the gap between hypodermal tissue and pharyngeal epithelium, the arcade cells also secrete a narrow ring of cuticle that seals the body cuticle of the lips to the buccal cuticle via a local, notched joint known as the cheilostom groove (InterFIG 1) (Wright, 1976, Wright and Thomson, 1981). Although, the cuticles of the body and buccal capsule are distinct in C. elegans, the cuticles of the different regions of the capsule are similar. Since body cuticle does not enter the buccal cavity, C. elegans is categorized as an “astomatous” species (Wright, 1976; Wright and Thomson, 1981). During molts, the cuticular linings of the buccal capsule and the pharynx are also shed. The body cuticle undergoes apolysis and a new cuticle is laid down before the apolysis of the buccal capsule cuticle and pharyngeal cuticle. Unlike body cuticle, pharyngeal cuticle and buccal capsule cuticle are broken down following apolysis. (Wright and Thomson, 1981; see Cuticle).
4 Development of the Buccal Cavity and the Anterior Foregut The morphogenesis of the pharynx starts at the late comma stage, after gastrulation is complete and approximately 330 minutes after first cell division. At this stage, 78 of the 80 pharyngeal cells have been born and the pharyngeal primordium has formed a cystic ball inside the embryo (InterFIG 5). This compact tissue borders the nascent intestine at the posterior and is connected to it by adherens junctions, but is not yet connected to the buccal cavity. The hypodermal and nine arcade cells fill the 11- to 12-μm space between the pharyngeal cells and the anterior of the embryo. Over the next 60 minutes, the pharyngeal cells go through a process called “pharyngeal extension,” when they convert from a cyst to a short, linear tube that links the digestive tract to the buccal cavity (InterFIG 5 and InterFIG 6) (Portereiko and Mango, 2001; Mango, 2007). Pharyngeal extension takes place through coordinate formation of new epithelia without any cell migrations and has three stages: reorientation of pharyngeal epithelial cells, epithelization of the arcade cells, which are originally mesenchymal, and contraction of the buccal cavity and the pharyngeal epithelial cells. During the first stage, pharyngeal epithelial cells rotate and reorient their apicobasal polarity along the dorsoventral axis from the rostrocaudal axis. This rearrangement aligns the pharyngeal epithelial cells of the anterior edge of the pharyngeal primordium with the arcade cells. During the second stage, the arcade cells form adherens junctions with the pharyngeal epithelium and the hypodermis, generating a continuous epithelium between the hypodermis and the anterior pharynx. The arcade cell epithelium is the last epithelium to form in the embryo, and its formation takes place in less than 10 minutes (Portereiko et al., 2004). In the last stage, contraction of the apical surface of this continuous epithelium pulls the cells together, moving the hypodermis backward while moving the pharynx forward (Portereiko and Mango, 2001). During later embryogenesis, the linear pharyngeal tube that forms at the end of pharyngeal extension develops a lumen and undergoes an extensive morphogenetic program to produce the characteristic two-lobed structure of the fully differentiated pharynx (see Alimentary System - Pharynx). IntFIG 5: Embryonic development of buccal cavity. A, C, E, F. Schematic views of buccal development. (Yellow) Arcade cells; (purple) pharyngeal epithelial cells; (dark green and light green) pharyngeal muscle cells. The anterior sensory deprivation (not a mouth opening) is indicated with a star in A. Black curved lines on cells indicate epithelization and apical-basal domain separation (Based on Portereiko and Mango, 2001; Mango, 2007). B, D, G DIC images corresponding to different embryonic stages: B comma stage; D 1.5-fold stage; G twofold stage. (Black arrowheads in DIC images) Basal lamina surrounding the pharynx primordium; (black arrows) pharyngeal epithelial cells; (white arrows) arcade cells. Buccal and anterior pharyngeal development has three stages: reorientation of pharyngeal epithelial cells (A-C), epithelization of arcade cells (D, E) and contraction of the arcade and pharyngeal epithelium (F, G). In the first stage, pharyngeal epithelial cells reorient their polarity to dorsoventral from rostrocaudal axis (double-headed arrows in A and C) to align with arcade cells. This rearrangement changes the shape of the pharynx from a cyst to a short tube. In the second stage, arcade cells become epithelialized, producing a continuous epithelium with the pharyngeal tissue and coupling the buccal cavity to the anterior hypodermis and the pharynx. In the last stage, apical surfaces of the arcades and pharyngeal epithelial cells constrict, pulling the pharynx anteriorly and the buccal opening posteriorly. A tube without a lumen is formed at the end of the third stage. InterFIG 6: Arcade cells in tadpole stage (1.7 fold) embryo. TEM, transverse section, dorsal is top. (Inset) Level of section in the head. Anterior sensory depression is on the right. Anterior arcade cell (beige line) reaches the future buccal opening, which is also surrounded by socket cells of the head sensilla and hyp1 and hyp 2. XXXR is not visible at this level. (Sd) Sensory depression; (aa) anterior arcade. Bar, 1 μm. (Image source: [MRC] Tadpole stage embryo-head A1009-5.) 5 List of Interfacial Epithelial Cells
1. Arcade cells arc ant DL arc ant DR arc ant V arc post D arc post DL arc post DR arc post V arc post VL arc post VR 2. Pharyngeal epithelium (see Pharynx) e1D e1VL e1VR e2DL e2DR e2V e3D e3VL e3VR 3. Rectal epithelium (see Rectum & Anus) B F Y U K' K K.a (aka Rect_hyp) 4. Vulval epithelium (see Egg-laying Apparatus) vulA vulB1 vulB2 vulC vulD vulE vulF | 5. Glia (see Neuronal Support Cells) ADEshL ADEshR AMshL AMshR CEPshDL CEPshDR CEPshVL CEPshVR ILshDL ILshDR ILshL ILshR ILshVL ILshVR OLLshL OLLshR OLQshDL OLQshDR OLQshVL OLQshVR PDEshL PDEshR PHshL PHshR ADEsoL ADEsoR AMsoL AMsoR CEPsoDL CEPsoDR CEPsoVL CEPsoVR ILsoDL ILsoDR ILsoL ILsoR ILsoVL ILsoVR | OLLsoL OLLsoR OLQsoDL OLQsoDR OLQsoVL OLQsoVR PDEsoL PDEsoR PHso1L PHso2L PHso1R PHso2R 6. Excretory duct and pore (see Excretory System) Excretory duct cell Excretory pore cell: - G1 (only at embryo stage) - G2 (only at L1 stage) - G2.p (L2 and later stages)
6 References Albert, P.S. and Riddle, D.L. 1988. Mutants of Caenorhabditis elegans that form dauer-like larvae. Dev. Biol. 126: 270-293. Abstract Bird, A.F. and Bird, J. 1991. Digestive System in The Structure of Nematodes. pp 183-229. S. Diego, CA, Academic Press. De Ley, P., Van De Velde, M.C., Mountport, D., Baujard, P. and Coomans, A. 1995. Ultrastructure of the stoma in Cephalobidae, Paragrolaimidae and Rhabditidae with proposal for a revised stoma terminology in Rhabditida (Nematoda). Nematologica 41:153-182. Abstract Dolinski, C., Borgonie, G., Schnabel, R. and Baldwin, J.G. 1998. Buccal capsule development as a consideration for phylogenetic analysis of Rhabditida (Nemata). Dev. Genes Evol. 208: 495-503. Abstract Mango, S.E. 2007. The C. elegans pharynx: A model for organogenesis. In Wormbook (ed. The C. elegans Research Community), doi/10.1895/wormbook.1.129.1. Article McKay, S.J., Johnsen, R., Khattra, J., Asano, J., Baillie, D.L., Chan, S., Dube, N., Fang, L., Goszczynsk,i B., Ha, K., Halfnight, E., Hollebakken, R., Huang, P., Hung, K., Jensen, V., Jones, S.J.M., Kai, H., Li, D., Mah,, A., Marr, M., McGhee, J., Newbury, R., Pouzyrev, A., Riddle, D.R., Sonnhammer, E., Tian, H., Tu, D., Tyson, J., Warner, A., Wong, K., Zhao, Z. and Moerman, D.G. 2004. Gene expression profiling of cells, tissues, and developmental stages of the nematode C. elegans. Cold Spring Harbor Symp. Quant. Biol. 68: 159-169. Abstract Portereiko, M.F. and Mango S.E. 2001. Early morphogenesis of the Caenorhabditis elegans pharynx. Dev. Biol. 233: 482-494. Article Portereiko, M.F., Saam, J. and Mango S.E. 2004. ZEN-4/MKLP1 is required to polarize the foregut epithelium. Curr. Biol. 14: 932-941. Abstract White J. 1988. The Anatomy. In The nematode C. elegans (ed. W. B. Wood). Chapter 4. pp 81-122. Cold Spring Harbor Laboratory Press, New York. Abstract Wright, K.A. 1976. In "The Organization of Nematodes" (N. A. Croll, ed.) pp71-105. Academic Press, London. Wright, K.A. and Thomson, J.N. 1981. The buccal capsule of C. elegans (Nematoda: Rhabditoidea): An ultrastructural study. Canad. J. Zool. 59: 1952-1961. Article
This chapter should be cited as: Altun, Z.F. and Hall, D.H. 2009. Epithelial system, interfacial cells. In WormAtlas. doi:10.3908/wormatlas.1.15 Edited for the web by Laura A. Herndon. Last revision: June 4, 2013.

©Copyright 2025 WormAtlas (Cold Spring Harbor Laboratory Press) All Rights Reserved |